==> resin-3.1.13-src.tar.gz: resin-3.1.13/modules/resin/src/com/caucho/server/rewrite/ConditionFilterChain.java <==
/*
 * Copyright (c) 1998-2008 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Sam
 */

package com.caucho.server.rewrite;

import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.*;
import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;

class ConditionFilterChain
  implements FilterChain
{
  private static final Logger log = Logger.getLogger(ConditionFilterChain.class.getName());

  private final String _logPrefix;
  private final String _uri;
  private final String _targetUri;
  private final FilterChain _failChain;
  private final Condition []_conditions;
  private final FilterChain _passChain;

  private final boolean _isFiner;
  private final boolean _isFinest;

  public ConditionFilterChain(String logPrefix,
                              String uri,
                              String targetUri,
                              Condition []conditions,
                              FilterChain passChain,
                              FilterChain failChain)
  {
    assert conditions != null;
    assert passChain != null;
    assert failChain != null;

    _logPrefix = logPrefix;
    _uri = uri;
    _targetUri = targetUri;

    _conditions = conditions;
    _passChain = passChain;
    _failChain = failChain;

    _isFiner = log.isLoggable(Level.FINER);
    _isFinest = log.isLoggable(Level.FINEST);
  }

  public void doFilter(ServletRequest request, ServletResponse response)
    throws ServletException, IOException
  {
    HttpServletRequest req = (HttpServletRequest) request;
    HttpServletResponse res = (HttpServletResponse) response;

    for (int i = 0; i < _conditions.length; i++) {
      if (! _conditions[i].isMatch(req, res)) {
	if (_isFiner)
	  log.finer(_logPrefix + " '" + _uri + "' --> '" + _targetUri + "'");
	
	_failChain.doFilter(request, response);
	return;
      }
    }

    if (_isFiner)
      log.finer(_logPrefix + " '" + _uri + "' --> '" + _targetUri + "'");
    
    _passChain.doFilter(request, response);
  }
}

==> resin-4.0.65-src.tar.gz: resin-4.0.65/modules/resin/src/com/caucho/server/rewrite/ConditionFilterChain.java <==
/*
 * Copyright (c) 1998-2018 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Sam
 */

package com.caucho.server.rewrite;

import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.caucho.server.http.HttpServletResponseImpl;

class ConditionFilterChain
  implements FilterChain
{
  private static final Logger log = Logger.getLogger(ConditionFilterChain.class.getName());

  private final String _logPrefix;
  private final String _uri;
  private final String _targetUri;
  private final FilterChain _failChain;
  private final Condition []_conditions;
  private final FilterChain _passChain;

  private final boolean _isFiner;
  private final boolean _isFinest;

  public ConditionFilterChain(String logPrefix,
                              String uri,
                              String targetUri,
                              Condition []conditions,
                              FilterChain passChain,
                              FilterChain failChain)
  {
    assert conditions != null;
    assert passChain != null;
    assert failChain != null;

    _logPrefix = logPrefix;
    _uri = uri;
    _targetUri = targetUri;

    _conditions = conditions;
    _passChain = passChain;
    _failChain = failChain;

    _isFiner = log.isLoggable(Level.FINER);
    _isFinest = log.isLoggable(Level.FINEST);
  }

  public void doFilter(ServletRequest request, ServletResponse response)
    throws ServletException, IOException
  {
    HttpServletRequest req = (HttpServletRequest) request;
    HttpServletResponse res = (HttpServletResponse) response;

    if (res instanceof HttpServletResponseImpl) {
      HttpServletResponseImpl cRes = (HttpServletResponseImpl) res;

      cRes.setNoCacheUnlessVary(true);
    }

    for (int i = 0; i < _conditions.length; i++) {
      if (! _conditions[i].isMatch(req, res)) {
        if (_isFiner)
          log.finer(_logPrefix + " '" + _uri + "' --> '" + _targetUri + "'");

        _failChain.doFilter(request, response);
        return;
      }
    }

    if (_isFiner)
      log.finer(_logPrefix + " '" + _uri + "' --> '" + _targetUri + "'");
    
    _passChain.doFilter(request, response);
  }
}
